@@ -1,38 +1,15 @@
 """Tests for common library."""
-from unittest.mock import patch
-
 import pytest
 
-from nile.common import BUILD_DIRECTORY, prepare_params, run_command, stringify
+from nile.common import parse_information, prepare_params, stringify
 
-CONTRACT = "contract"
-OPERATION = "invoke"
 NETWORK = "goerli"
 ARGS = ["1", "2", "3"]
 LIST1 = [1, 2, 3]
 LIST2 = [1, 2, 3, [4, 5, 6]]
 LIST3 = [1, 2, 3, [4, 5, 6, [7, 8, 9]]]
-
-
-@pytest.mark.parametrize("operation", ["invoke", "call"])
-@patch("nile.common.subprocess.check_output")
-def test_run_command(mock_subprocess, operation):
-
-    run_command(
-        contract_name=CONTRACT, network=NETWORK, operation=operation, arguments=ARGS
-    )
-
-    mock_subprocess.assert_called_once_with(
-        [
-            "starknet",
-            operation,
-            "--contract",
-            f"{BUILD_DIRECTORY}/{CONTRACT}.json",
-            "--inputs",
-            *ARGS,
-            "--no_wallet",
-        ]
-    )
+STDOUT_1 = "SDTOUT_1"
+STDOUT_2 = "SDTOUT_2"
 
 
 @pytest.mark.parametrize(
@@ -62,3 +39,12 @@ def test_stringify(args, expected):
 )
 def test_prepare_params(args, expected):
     assert prepare_params(args) == expected
+
+
+def test_parse_information():
+    a = format(1, "#066x")
+    b = format(2, "#066x")
+    target = f"Formatting 'a': {a}. Formatting 'b': {b}."
+
+    _a, _b = parse_information(target)
+    assert _a, _b == (a, b)
