@@ -8,13 +8,16 @@ import asyncio
 
 import pytest
 from starkware.starknet.business_logic.transaction.objects import InternalTransaction
+from starkware.starknet.definitions.general_config import StarknetChainId
 from starkware.starknet.services.api.contract_class import ContractClass
 from starkware.starknet.services.api.gateway.transaction import InvokeFunction
 from starkware.starknet.testing.starknet import Starknet
 
-from nile.signer import TRANSACTION_VERSION, Signer, from_call_to_call_array
+from nile.common import TRANSACTION_VERSION
+from nile.signer import Signer, from_call_to_call_array
 
-SIGNER = Signer(12345678987654321)
+PRIVATE_KEY = 12345678987654321
+SIGNER = Signer(PRIVATE_KEY)
 
 
 def get_account_definition():
@@ -39,8 +42,8 @@ async def send_transactions(signer, account, calls, nonce=None, max_fee=0):
         nonce = await state.state.get_nonce_at(account.contract_address)
 
     # get signature
-    calldata, sig_r, sig_s = signer.sign_transaction(
-        account.contract_address, calls, nonce, max_fee
+    calldata, sig_r, sig_s = signer.sign_invoke(
+        account.contract_address, calls, nonce, max_fee, TRANSACTION_VERSION
     )
 
     # craft invoke and execute tx
@@ -105,6 +108,18 @@ async def test_execute():
     assert execution_info.result == (3,)
 
 
+@pytest.mark.asyncio
+async def test_chain_id():
+    mainnet = Signer(PRIVATE_KEY, "mainnet")
+    assert mainnet.chain_id == StarknetChainId.MAINNET.value
+
+    testnet = Signer(PRIVATE_KEY, "testnet")
+    assert testnet.chain_id == StarknetChainId.TESTNET.value
+
+    no_network = Signer(PRIVATE_KEY)
+    assert no_network.chain_id == StarknetChainId.TESTNET.value
+
+
 def get_raw_invoke(sender, calls):
     """Construct and return StarkNet's internal raw_invocation."""
     call_array, calldata = from_call_to_call_array(calls)
